<p align="center">
  <a href="{website_url}"><b>[🌐 Website]</b></a> •
  <a href="{github_url}"><b>[🐱 GitHub]</b></a>
  <a href="{twitter_url}"><b>[🐦 Twitter]</b></a> •
  <a href="{blog_url}"><b>[🍀 Official Blog]</b></a>
</p>